@@ -12,17 +12,15 @@ def get_arp_table():
     """
     with open('/proc/net/arp') as arpt:
         names = [
-            'IP address', 'HW type', 'Flags', 'HW address',
-            'Mask', 'Device'
+            'IP address', 'HW type', 'Flags', 'HW address', 'Mask', 'Device'
         ]  # arp 1.88, net-tools 1.60
 
         reader = csv.DictReader(
-            arpt, fieldnames=names,
-            skipinitialspace=True,
-            delimiter=' ')
+            arpt, fieldnames=names, skipinitialspace=True, delimiter=' ')
 
         next(reader)  # Skip header.
 
         return [block for block in reader]
 
+
 ARPTABLE = get_arp_table()
